pub enum LocationMatchingStrategy {
DeveloperMetadataLocationMatchingStrategyUnspecified,
ExactLocation,
IntersectingLocation,
Noop,
FallthroughString,
}Expand description
Determines how this lookup matches the location. If this field is specified as EXACT, only developer metadata associated on the exact location specified is matched. If this field is specified to INTERSECTING, developer metadata associated on intersecting locations is also matched. If left unspecified, this field assumes a default value of INTERSECTING. If this field is specified, a metadataLocation must also be specified.
Variants
DeveloperMetadataLocationMatchingStrategyUnspecified
ExactLocation
IntersectingLocation
Noop
FallthroughString
Implementations