pub struct AddSheetRequest {
pub properties: Option<SheetProperties>,
}Expand description
Adds a new sheet. When a sheet is added at a given index, all subsequent sheets’ indexes are incremented. To add an object sheet, use AddChartRequest instead and specify EmbeddedObjectPosition.sheetId or EmbeddedObjectPosition.newSheet.
Fields
properties: Option<SheetProperties>Adds a new sheet. When a sheet is added at a given index, all subsequent sheets’ indexes are incremented. To add an object sheet, use AddChartRequest instead and specify EmbeddedObjectPosition.sheetId or EmbeddedObjectPosition.newSheet.