pub struct BasicChartDomain {
pub domain: Option<ChartData>,
pub reversed: bool,
}Expand description
The domain of a chart. For example, if charting stock prices over time, this would be the date.
Fields
domain: Option<ChartData>The domain of a chart. For example, if charting stock prices over time, this would be the date.
reversed: boolThe domain of a chart. For example, if charting stock prices over time, this would be the date.