pub struct ChartDateTimeRule {
pub type_: Option<ChartDateTimeRuleType>,
}Expand description
Allows you to organize the date-time values in a source data column into buckets based on selected parts of their date or time values.
Fields
type_: Option<ChartDateTimeRuleType>Allows you to organize the date-time values in a source data column into buckets based on selected parts of their date or time values.