pub struct DataSource {
pub calculated_columns: Vec<DataSourceColumn>,
pub data_source_id: String,
pub sheet_id: i64,
pub spec: Option<DataSourceSpec>,
}Expand description
Information about an external data source in the spreadsheet.
Fields
calculated_columns: Vec<DataSourceColumn>Information about an external data source in the spreadsheet.
data_source_id: StringInformation about an external data source in the spreadsheet.
sheet_id: i64Information about an external data source in the spreadsheet.
spec: Option<DataSourceSpec>Information about an external data source in the spreadsheet.