pub struct FindReplaceRequest {
pub all_sheets: Option<bool>,
pub find: String,
pub include_formulas: Option<bool>,
pub match_case: Option<bool>,
pub match_entire_cell: Option<bool>,
pub range: Option<GridRange>,
pub replacement: String,
pub search_by_regex: Option<bool>,
pub sheet_id: i64,
}Expand description
Finds and replaces data in cells over a range, sheet, or all sheets.
Fields
all_sheets: Option<bool>Finds and replaces data in cells over a range, sheet, or all sheets.
find: StringFinds and replaces data in cells over a range, sheet, or all sheets.
include_formulas: Option<bool>Finds and replaces data in cells over a range, sheet, or all sheets.
match_case: Option<bool>Finds and replaces data in cells over a range, sheet, or all sheets.
match_entire_cell: Option<bool>Finds and replaces data in cells over a range, sheet, or all sheets.
range: Option<GridRange>Finds and replaces data in cells over a range, sheet, or all sheets.
replacement: StringFinds and replaces data in cells over a range, sheet, or all sheets.
search_by_regex: Option<bool>Finds and replaces data in cells over a range, sheet, or all sheets.
sheet_id: i64Finds and replaces data in cells over a range, sheet, or all sheets.