pub struct OverlayPosition {
pub anchor_cell: Option<GridCoordinate>,
pub height_pixels: i64,
pub offset_x_pixels: i64,
pub offset_y_pixels: i64,
pub width_pixels: i64,
}Expand description
The location an object is overlaid on top of a grid.
Fields
anchor_cell: Option<GridCoordinate>The location an object is overlaid on top of a grid.
height_pixels: i64The location an object is overlaid on top of a grid.
offset_x_pixels: i64The location an object is overlaid on top of a grid.
offset_y_pixels: i64The location an object is overlaid on top of a grid.
width_pixels: i64The location an object is overlaid on top of a grid.