pub struct Padding {
pub bottom: i64,
pub left: i64,
pub right: i64,
pub top: i64,
}Expand description
The amount of padding around the cell, in pixels. When updating padding, every field must be specified.
Fields
bottom: i64The amount of padding around the cell, in pixels. When updating padding, every field must be specified.
left: i64The amount of padding around the cell, in pixels. When updating padding, every field must be specified.
right: i64The amount of padding around the cell, in pixels. When updating padding, every field must be specified.
top: i64The amount of padding around the cell, in pixels. When updating padding, every field must be specified.