pub struct PivotGroupSortValueBucket {
pub buckets: Vec<ExtendedValue>,
pub values_index: i64,
}Expand description
Information about which values in a pivot group should be used for sorting.
Fields
buckets: Vec<ExtendedValue>Information about which values in a pivot group should be used for sorting.
values_index: i64Information about which values in a pivot group should be used for sorting.