pub struct RefreshDataSourceResponse {
pub statuses: Vec<RefreshDataSourceObjectExecutionStatus>,
}Expand description
The response from refreshing one or multiple data source objects.
Fields
statuses: Vec<RefreshDataSourceObjectExecutionStatus>The response from refreshing one or multiple data source objects.