pub struct TextColumnsRequest {
pub delimiter: String,
pub delimiter_type: Option<DelimiterType>,
pub source: Option<GridRange>,
}Expand description
Splits a column of text into multiple columns, based on a delimiter in each cell.
Fields
delimiter: StringSplits a column of text into multiple columns, based on a delimiter in each cell.
delimiter_type: Option<DelimiterType>Splits a column of text into multiple columns, based on a delimiter in each cell.
source: Option<GridRange>Splits a column of text into multiple columns, based on a delimiter in each cell.